Build a population stability whitelist from euploid controls
niptmer_ref_stability_whitelist.RdFor ultra-low-coverage cohorts, use pool_mode = "block" so filtering is
applied to pooled control blocks instead of individual samples.
Usage
niptmer_ref_stability_whitelist(
control_lists = NULL,
control_fastq = NULL,
k = 25,
pool_mode = c("block", "none"),
block_size = 50,
n_blocks = NULL,
depth_mode = c("auto", "given"),
depth_values = NULL,
model = c("poisson", "nbinom"),
distribution_max = 500,
lower_p = 0.01,
upper_p = 0.99,
min_block_support = 0.7,
out_prefix = "stable_whitelist",
out_dir = ".",
threads = 1
)Arguments
- control_lists
Optional vector of pre-built GenomeTester4 list files.
- control_fastq
Optional vector of FASTQ/FASTA files. If provided, per-sample lists are built with
glistmaker.- k
K-mer size.
- pool_mode
Either
"block"or"none".- block_size
Number of controls per block when
pool_mode = "block".- n_blocks
Optional explicit number of blocks.
- depth_mode
Either
"auto"(estimate from each pooled list) or"given"(usedepth_values).- depth_values
Optional numeric depth values for each block when
depth_mode = "given".- model
Distribution model used for cutoff estimation:
"poisson"or"nbinom".- distribution_max
Maximum count inspected from
glistquery --distributionwhen estimating coverage/dispersion.- lower_p
Lower cumulative probability cutoff.
- upper_p
Upper cumulative probability cutoff.
- min_block_support
Minimum support threshold across blocks. If <= 1, interpreted as a fraction; otherwise interpreted as number of blocks.
- out_prefix
Output prefix for final whitelist.
- out_dir
Output directory.
- threads
Number of threads used when building lists from FASTQ.